@@ -1,3 +1,4 @@
+import traceback
 from typing import Any, Dict, Union
 from aws_lambda_powertools import Logger
 from threading import local
@@ -8,12 +9,16 @@ class FyersLogger(Logger):
     __fyId = local()
     __requestId = local()
 
-    def __init__(self, service: str, level: str, **kwargs) -> None:
+    def __init__(self, service: str, level: str, stack_level: int=4, **kwargs) -> None:
         """Create FyersLogger object
 
         Args:
             service (str): Service name. This should be the same across the code wherever the logger is initialized
             level (str): Logger level. Possible values are [INFO, DEBUG, CRITICAL, WARNING]
+
+        Kwargs:
+            stack_level (int): Stack level. This decides how many levels the stack should go up to get the line number
+                            to be printed in the logging statement
         """
         super().__init__(
             service=service,
@@ -23,7 +28,7 @@ class FyersLogger(Logger):
         )
         self.__fyId.val = ""
         self.__requestId.val = ""
-        self.__stacklevel = 4
+        self.__stacklevel = stack_level
 
     def set_fyId(self, fyId: str) -> None:
         """Sets FyId for a particular request. This function needs to be called only once for each request
@@ -41,12 +46,13 @@ class FyersLogger(Logger):
         """
         self.__requestId.val = requestId
 
-    def __populate_request_data(self, **kwargs) -> Dict[str, Any]:
+    def __populate_request_data(self, stack_level, **kwargs) -> Dict[str, Any]:
         """Adds additional log data to log statement
 
         Returns:
             Dict[str, Any]: all the keyword arguments along with extra data
         """
+        kwargs["stacklevel"] = stack_level
         if "extra" not in kwargs:
             kwargs["extra"] = {}
 
@@ -68,8 +74,8 @@ class FyersLogger(Logger):
         stacklevel = self.__stacklevel
         while stacklevel > 0:
             try:
-                kwargs = self.__populate_request_data(**kwargs)
-                super().error(msg, *args, stacklevel=stacklevel, **kwargs)
+                kwargs = self.__populate_request_data(stacklevel, **kwargs)
+                super().error(msg, *args, **kwargs)
                 break
             except:
                 stacklevel -= 1
@@ -86,8 +92,8 @@ class FyersLogger(Logger):
         stacklevel = self.__stacklevel
         while stacklevel > 0:
             try:
-                kwargs = self.__populate_request_data(**kwargs)
-                super().info(msg, *args, stacklevel=stacklevel, **kwargs)
+                kwargs = self.__populate_request_data(stacklevel, **kwargs)
+                super().info(msg, *args, **kwargs)
                 break
             except:
                 stacklevel -= 1
@@ -104,8 +110,8 @@ class FyersLogger(Logger):
         stacklevel = self.__stacklevel
         while stacklevel > 0:
             try:
-                kwargs = self.__populate_request_data(**kwargs)
-                super().debug(msg, *args, stacklevel=stacklevel, **kwargs)
+                kwargs = self.__populate_request_data(stacklevel, **kwargs)
+                super().debug(msg, *args, **kwargs)
                 break
             except:
                 stacklevel -= 1
@@ -122,8 +128,8 @@ class FyersLogger(Logger):
         stacklevel = self.__stacklevel
         while stacklevel > 0:
             try:
-                kwargs = self.__populate_request_data(**kwargs)
-                super().exception(msg, *args, stacklevel=stacklevel, **kwargs)
+                kwargs = self.__populate_request_data(stacklevel, **kwargs)
+                super().exception(msg, *args, **kwargs)
                 break
             except:
                 stacklevel -= 1
